Installation
===================
This package is available in PyPI. Just run the following command on terminal to install.

>>> pip install pyscisci

You can also source the code directly from the github `project page <https://github.com/SciSciCollective/pyscisci>`_ .